@@ -1,5 +1,5 @@
 /***************************************************************************
-* Copyright (c) 2016, Johan Mabille and Sylvain Corlay                     *
+* Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht    *
 *                                                                          *
 * Distributed under the terms of the BSD 3-Clause License.                 *
 *                                                                          *
@@ -147,6 +147,12 @@ namespace xt
         UNARY_MATH_FUNCTOR(erfc);
         UNARY_MATH_FUNCTOR(tgamma);
         UNARY_MATH_FUNCTOR(lgamma);
+        UNARY_MATH_FUNCTOR(ceil);
+        UNARY_MATH_FUNCTOR(floor);
+        UNARY_MATH_FUNCTOR(trunc);
+        UNARY_MATH_FUNCTOR(round);
+        UNARY_MATH_FUNCTOR(nearbyint);
+        UNARY_MATH_FUNCTOR(rint);
         UNARY_BOOL_FUNCTOR(isfinite);
         UNARY_BOOL_FUNCTOR(isinf);
         UNARY_BOOL_FUNCTOR(isnan);
@@ -895,6 +901,113 @@ namespace xt
         return detail::make_xfunction<math::lgamma_fun>(std::forward<E>(e));
     }
 
+    /*********************************************
+     * nearest integer floating point operations *
+     *********************************************/
+
+     /**
+      * @defgroup nearint_functions Nearest integer floating point operations
+      */
+
+      /**
+       * @ingroup nearint_functions
+       * @brief ceil function.
+       *
+       * Returns an \ref xfunction for the element-wise smallest integer value
+       * not less than \em e.
+       * @param e an \ref xexpression
+       * @return an \ref xfunction
+       */
+    template <class E>
+    inline auto ceil(E&& e) noexcept
+        -> detail::xfunction_type_t<math::ceil_fun, E>
+    {
+        return detail::make_xfunction<math::ceil_fun>(std::forward<E>(e));
+    }
+
+    /**
+    * @ingroup nearint_functions
+    * @brief floor function.
+    *
+    * Returns an \ref xfunction for the element-wise smallest integer value
+    * not greater than \em e.
+    * @param e an \ref xexpression
+    * @return an \ref xfunction
+    */
+    template <class E>
+    inline auto floor(E&& e) noexcept
+        -> detail::xfunction_type_t<math::floor_fun, E>
+    {
+        return detail::make_xfunction<math::floor_fun>(std::forward<E>(e));
+    }
+
+    /**
+    * @ingroup nearint_functions
+    * @brief trunc function.
+    *
+    * Returns an \ref xfunction for the element-wise nearest integer not greater
+    * in magnitude than \em e.
+    * @param e an \ref xexpression
+    * @return an \ref xfunction
+    */
+    template <class E>
+    inline auto trunc(E&& e) noexcept
+        -> detail::xfunction_type_t<math::trunc_fun, E>
+    {
+        return detail::make_xfunction<math::trunc_fun>(std::forward<E>(e));
+    }
+
+    /**
+     * @ingroup nearint_functions
+     * @brief round function.
+     *
+     * Returns an \ref xfunction for the element-wise nearest integer value
+     * to \em e, rounding halfway cases away from zero, regardless of the
+     * current rounding mode.
+     * @param e an \ref xexpression
+     * @return an \ref xfunction
+     */
+    template <class E>
+    inline auto round(E&& e) noexcept
+        -> detail::xfunction_type_t<math::round_fun, E>
+    {
+        return detail::make_xfunction<math::round_fun>(std::forward<E>(e));
+    }
+
+    /**
+     * @ingroup nearint_functions
+     * @brief nearbyint function.
+     *
+     * Returns an \ref xfunction for the element-wise rounding of \em e to integer
+     * values in floating point format, using the current rounding mode. nearbyint
+     * never raises FE_INEXACT error.
+     * @param e an \ref xexpression
+     * @return an \ref xfunction
+     */
+    template <class E>
+    inline auto nearbyint(E&& e) noexcept
+        -> detail::xfunction_type_t<math::nearbyint_fun, E>
+    {
+        return detail::make_xfunction<math::nearbyint_fun>(std::forward<E>(e));
+    }
+
+    /**
+     * @ingroup nearint_functions
+     * @brief rint function.
+     *
+     * Returns an \ref xfunction for the element-wise rounding of \em e to integer
+     * values in floating point format, using the current rounding mode. Contrary
+     * to nearbyint, rint may raise FE_INEXACT error.
+     * @param e an \ref xexpression
+     * @return an \ref xfunction
+     */
+    template <class E>
+    inline auto rint(E&& e) noexcept
+        -> detail::xfunction_type_t<math::rint_fun, E>
+    {
+        return detail::make_xfunction<math::rint_fun>(std::forward<E>(e));
+    }
+
     /****************************
      * classification functions *
      ****************************/
@@ -995,46 +1108,46 @@ namespace xt
             bool m_equal_nan;
         };
     }
+
     /**
      * @ingroup classif_functions
      * @brief Element-wise closeness detection
      *
      * Returns an \ref xfunction that evaluates to
-     * true if the element in e1 and e2 are close to each other
+     * true if the elements in ``e1`` and ``e2`` are close to each other
      * according to parameters ``atol`` and ``rtol``.
      * The equation is: ``std::abs(a - b) <= (m_atol + m_rtol * std::abs(b))``.
-     *
-     * @param e1, @param e2 input arrays to compare
+     * @param e1 input array to compare
+     * @param e2 input array to compare
      * @param rtol the relative tolerance parameter (default 1e-05)
      * @param atol the absolute tolerance parameter (default 1e-08)
-     * @param equal_nan if true, isclose returns true if both elements of a and b are NaN
+     * @param equal_nan if true, isclose returns true if both elements of e1 and e2 are NaN
      * @return an \ref xfunction
      */
     template <class E1, class E2>
-    inline auto isclose(E1&& a, E2&& b, double rtol = 1e-05, double atol = 1e-08, bool equal_nan = false) noexcept
+    inline auto isclose(E1&& e1, E2&& e2, double rtol = 1e-05, double atol = 1e-08, bool equal_nan = false) noexcept
     {
         return detail::make_xfunction<detail::isclose>(std::make_tuple(rtol, atol, equal_nan),
-                                                       std::forward<E1>(a), std::forward<E2>(b));
+                                                       std::forward<E1>(e1), std::forward<E2>(e2));
     }
 
     /**
      * @ingroup classif_functions
-     * @brief Check if all elements in \em a are close to the
-     * corresponding elements in \em b.
+     * @brief Check if all elements in \em e1 are close to the
+     * corresponding elements in \em e2.
      *
-     * Returns an \ref xfunction that evaluates to
-     * true if all elements in e1 and e2 are close to each other
+     * Returns true if all elements in ``e1`` and ``e2`` are close to each other
      * according to parameters ``atol`` and ``rtol``.
-     * @param e1, @param e2 input arrays to compare
+     * @param e1 input array to compare
+     * @param e2 input arrays to compare
      * @param rtol the relative tolerance parameter (default 1e-05)
      * @param atol the absolute tolerance parameter (default 1e-08)
-     * @param equal_nan if true, isclose returns true if both elements of a and b are NaN
-     * @return an \ref xfunction
+     * @return a boolean
      */
     template <class E1, class E2>
-    inline auto allclose(E1&& a, E2&& b, double rtol = 1e-05, double atol = 1e-08) noexcept
+    inline auto allclose(E1&& e1, E2&& e2, double rtol = 1e-05, double atol = 1e-08) noexcept
     {
-        return xt::all(isclose(std::forward<E1>(a), std::forward<E2>(b), rtol, atol));
+        return xt::all(isclose(std::forward<E1>(e1), std::forward<E2>(e2), rtol, atol));
     }
 
     /**********************
